netapp_ontap.models.autosupport_issues API documentation
Description: Copyright &copy; 2020 NetApp Inc. All rights reserved.

# Module `netapp_ontap.models.autosupport_issues`

Copyright © 2020 NetApp Inc. All rights reserved.

## Classes

`class AutosupportIssuesSchema (*, only: typing.Union = None, exclude: typing.Union = (), many: bool = False, context: typing.Dict = None, load_only: typing.Union = (), dump_only: typing.Union = (), partial: typing.Union = False, unknown: str = None)`

  The fields of the AutosupportIssues object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC

  ### Class variables

  `corrective_action GET POST PATCH`

    The corrective_action field of the autosupport_issues.

  `issue GET POST PATCH`

    The issue field of the autosupport_issues.

  `node GET POST PATCH`

    The node field of the autosupport_issues.